# CHANGELOG

## 0.4.0

- Safer template filling, and option to ignore slots [#20](https://github.com/opendp/dp-wizard-templates/pull/20)
- Check for `root` kwarg, and fix test coverage [#19](https://github.com/opendp/dp-wizard-templates/pull/19)

## 0.3.0

- Show all errors, and support comment blocks [#12](https://github.com/opendp/dp-wizard-templates/pull/12)

## 0.2.0

- Link to ghpages [#7](https://github.com/opendp/dp-wizard-templates/pull/7)
- Add black, and a generated index.html [#6](https://github.com/opendp/dp-wizard-templates/pull/6)

## 0.1.0

Initial release